@@ -1,4 +1,4 @@
-# -*- coding: Latin-1 -*-
+# -*- coding: utf-8 -*-
 """Graphviz dot language parser.
 
 This parser is derived from the the parser distributed with the pydot module.
@@ -8,13 +8,14 @@ Michael Krause <michael AT krause-software.de>
 Ero Carrera <ero AT dkbza.org>
 """
 
-__version__ = '2.8.4'
+__version__ = '2.8.5'
 __author__ = ['Michael Krause', 'Ero Carrera', 'Kjell Magne Fauske']
 __license__ = 'MIT'
 
 import sys, glob, re, itertools,os,logging
 
 from itertools import izip
+import string
 
 from exceptions import KeyError, AttributeError
 
@@ -419,7 +420,7 @@ class DotDataParser(object):
         node_      = CaselessLiteral("node")
         edge_      = CaselessLiteral("edge")
 
-
+        punctuation_ = "".join( [ c for c in string.punctuation if c not in '_' ] ) +string.whitespace
         # token definitions
 
         identifier = Word(alphanums + "_" ).setName("identifier")
@@ -430,11 +431,9 @@ class DotDataParser(object):
         double_quoted_string.setParseAction(removeQuotes)
         quoted_string = Combine(double_quoted_string+
             Optional(OneOrMore(pluss+double_quoted_string)),adjacent=False)
-
-        alphastring_ = OneOrMore(CharsNotIn(_noncomma))
+        alphastring_ = OneOrMore(CharsNotIn(punctuation_))
 
         def parse_html(s, loc, toks):
-
             return '<<%s>>' % ''.join(toks[0])
 
 
@@ -453,9 +452,9 @@ class DotDataParser(object):
             html_text = Combine(Literal("<<") + OneOrMore(CharsNotIn(",]")))
 
 
-        ID = ( identifier | html_text |
+        ID = ( alphastring_ | html_text |
             quoted_string | #.setParseAction(strip_quotes) |
-            alphastring_ ).setName("ID")
+            identifier ).setName("ID")
 
 
         float_number = Combine(Optional(minus) +
@@ -1129,8 +1128,9 @@ def parse_dot_data(data):
 testgraph = r"""
 /* Test that the various id types are parsed correctly */
 digraph G {
-
-    "aa\\" -> b [label="12"];
+    TPR [label=TехПрог];
+    LFP [label=ЛиФП, pos="420,686", width="0.86"];
+    //"aa\\" -> b [label="12"];
 }
 """
 
